aboutsummaryrefslogtreecommitdiff
path: root/contrib/python/examples/eg_attach.py
diff options
context:
space:
mode:
Diffstat (limited to 'contrib/python/examples/eg_attach.py')
-rw-r--r--contrib/python/examples/eg_attach.py13
1 files changed, 7 insertions, 6 deletions
diff --git a/contrib/python/examples/eg_attach.py b/contrib/python/examples/eg_attach.py
index f8008163f..f5070dc53 100644
--- a/contrib/python/examples/eg_attach.py
+++ b/contrib/python/examples/eg_attach.py
@@ -1,5 +1,5 @@
#!/usr/bin/env python3
"""Example: Run Alpine container and attach."""
import podman
@@ -8,10 +8,11 @@ print('{}\n'.format(__doc__))
with podman.Client() as client:
id = client.images.pull('alpine:latest')
img = client.images.get(id)
- cntr = img.create()
- cntr.start()
+ cntr = img.create(detach=True, tty=True, command=['/usr/bin/top'])
+ cntr.attach(eot=4)
try:
- cntr.attach()
- except BrokenPipeError:
- print('Container disconnected.')
+ cntr.start()
+ print()
+ except (BrokenPipeError, KeyboardInterrupt):
+ print('\nContainer disconnected.')
@@ -1,5 +1,5 @@
#!/usr/bin/env python3
-"""Example: Run Alpine container and attach."""
+"""Example: Run top on Alpine container."""
import podman